@@ -13,6 +13,11 @@
 #'   Options are TTO or VAS for EQ-5D-3L, VT for EQ-5D-5L or CW for EQ-5D-5L 
 #'   crosswalk conversion valuesets.
 #' @param country string of value set country name used.
+#' @param ignore.incomplete logical to indicate whether to ignore dimension 
+#'   with missing data.
+#' @param ... character vectors, specifying "dimensions" column names or 
+#'   "five.digit" column name. Defaults are "MO", "SC", "UA", "PD" and "AD"
+#'   for dimensions and "State" for five.digit.
 #' @examples
 #' eq5d(scores=c(MO=1,SC=2,UA=3,PD=4,AD=5), type="VT", 
 #'  country="Indonesia", version="5L")
@@ -21,9 +26,9 @@
 #' 
 #' scores.df <- data.frame(
 #'   MO=c(1,2,3,4,5), SC=c(1,5,4,3,2),
-#'   UA=c(1,5,2,3,1), PD=c(1,3,4,3,4), AD=c(1,2,1,2,1)
+#'   UA=c(1,5,2,3,1), PD=c(1,3,4,3,4), AD=c(1,2,NA,2,1)
 #'   )
-#' eq5d(scores.df, country="Canada", version="5L", type="VT")
+#' eq5d(scores.df, country="Canada", version="5L", type="VT", ignore.incomplete=TRUE)
 #'
 #' eq5d(scores=12321, type="TTO", version="3L", country="UK")
 #'
@@ -31,25 +36,41 @@
 #'   state=c(11111,12121,23232,33333)
 #' )
 #' 
-#' eq5d(scores=scores.df2, type="TTO", version="3L", country="UK")
+#' eq5d(scores=scores.df2, type="TTO", version="3L", country="UK", five.digit="state")
 #'
 #' @export
-eq5d <- function (scores, version, type, country) {
+eq5d <- function (scores, version, type, country, ignore.incomplete, ...) {
   UseMethod("eq5d", scores)
 }
 
 #' @export
-eq5d.numeric <- function(scores, version=NULL, type=NULL, country=NULL) {
-  
+eq5d.numeric <- function(scores, version=NULL, type=NULL, country=NULL, ignore.incomplete=FALSE, ...) {
+
   if(!version %in% c("3L", "5L"))
     stop("EQ-5D version not one of 3L or 5L.")
   
-  if(is.numeric(scores[1]) & nchar(scores[1])==5 & scores[1] >= 11111 & scores[1] <= 11111 * as.numeric(sub("L", "", version))) {
-    scores <- as.numeric(strsplit(as.character(scores[1]), "")[[1]])
-    names(scores) <- c("MO", "SC", "UA", "PD", "AD")    
+  if(any(is.na(scores))) {
+    if(ignore.incomplete) {
+      return(NA)
+    } else {
+      stop("Missing/non-numeric dimension found.")
+    }
   }
   
-  if(!all(names(scores) %in% c("MO", "SC", "UA", "PD", "AD"))) {
+  if(length(scores)==1) {
+    if(is.numeric(scores[1]) & scores[1] %in% .getDimensionCombinations(version)) {
+      scores <- as.numeric(strsplit(as.character(scores[1]), "")[[1]])
+      names(scores) <- c("MO", "SC", "UA", "PD", "AD")    
+    } else {
+      if(ignore.incomplete) {
+        return(NA)
+      } else {
+        stop("Invalid dimension state found.")
+      }
+    }
+  }
+
+  if(!all(c("MO", "SC", "UA", "PD", "AD") %in% names(scores))) {
     stop("Unable to identify EQ-5D dimensions in scores.")
   }
 
@@ -67,9 +88,26 @@ eq5d.numeric <- function(scores, version=NULL, type=NULL, country=NULL) {
 }
 
 #' @export
-eq5d.data.frame <- function(scores, version=NULL, type=NULL, country=NULL) {
+eq5d.data.frame <- function(scores, version=NULL, type=NULL, country=NULL, ignore.incomplete=FALSE, ...) {
+  args <- list(...)
+  
+  dimensions <- c("MO", "SC", "UA", "PD", "AD")
+  five.digit <- "State"
+
+  if(!is.null(args$dimensions)) {dimensions <- args$dimensions}
+  if(!is.null(args$five.digit)) {five.digit <- args$five.digit}
+
+  if(all(dimensions %in% names(scores))) {
+    scores <- scores[,dimensions]
+    colnames(scores) <- c("MO", "SC", "UA", "PD", "AD")
+  } else if(five.digit %in% names(scores)) {
+    scores <- scores[,five.digit, drop=FALSE]
+  } else {
+    stop("Unable to identify EQ-5D dimensions in data.frame.")
+  }
+  
   indices <- apply(scores, 1, function(x) {
-    eq5d.numeric(x, version=version, type=type, country=country)
+    eq5d.numeric(x, version=version, type=type, country=country, ignore.incomplete=ignore.incomplete)
   })
   
   return(indices)
@@ -107,3 +145,10 @@ valuesets <- function(type=NULL, version=NULL, country=NULL) {
   rownames(vs) <- NULL
   return(vs)
 }
+
+.getDimensionCombinations <- function(version) {
+  max.value <- sub("L", "", version)
+  dimensions <- expand.grid(1:max.value, 1:max.value, 1:max.value, 1:max.value, 1:max.value)
+  indexes <- apply(dimensions, 1, function(x){paste(x, collapse="")})
+  return(indexes)
+}
